<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

require_once dirname(__FILE__).'/../../vendor/autoload.php';

use Invertus\SwedBank\Config\Config;
use Invertus\SwedBank\Controller\AbstractAdminController;

class AdminSwedBankConfigurationController extends AbstractAdminController
{
    public function __construct()
    {
        parent::__construct();

        $this->page_header_toolbar_title = $this->l('Swedbank Country configuration');
    }

    public function init()
    {
        parent::init();

        $this->initOptions();
    }

    public function setMedia($isNewTheme = false)
    {
        $this->addJS($this->getAdminJsUrl().'settings.js');
        parent::setMedia();
    }

    public function postProcess()
    {
        if (!Tools::isSubmit('submitOptionsconfiguration')) {
            return parent::postProcess();
        }

        parent::postProcess();
        Tools::redirectAdmin($this->context->link->getAdminLink($this->controller_name).
            '&conf='.Config::CONFIRMATION_MESSAGE_ID);
    }

    private function initOptions()
    {
        $selectedName = $this->getStoredBankConfigurationName();

        $this->context->smarty->assign([
            'settingsNote' => $this->l('Please note: only one country can be active at the moment.'),
            'notificationUrl' => $this->context->link->getModuleLink(
                $this->module->name,
                'notification',
                [
                    'secret_key' => Tools::encrypt($this->module->name)
                ]
            ),
            'cronTaskUrl' => Tools::getShopDomainSsl(true).
                $this->module->getPathUri().'swedbank.cron.php?swedbankToken='.
                Tools::encrypt($this->module->name),
            'cronTaskPath' => $this->module->getLocalPath().'swedbank.cron.php',
            'swedBankToken' => Tools::encrypt($this->module->name)
        ]);

        $this->fields_options = [
            [
                'title' => $this->l('Settings'),
                'description' => $this->context->smarty->fetch(
                    $this->module->getLocalPath().'views/templates/admin/configuration-description.tpl'
                ),
                'fields' => [
                    Config::BANK_LT => [
                        'title' => $this->l('Lithuania banks'),
                        'validation' => 'isBool',
                        'cast' => 'intval',
                        'type' => 'bool',
                        'disabled' => (Config::BANK_LT !== $selectedName && 0 !== $selectedName) ? true : false
                    ],
                    Config::BANK_LV => [
                        'title' => $this->l('Latvia banks'),
                        'validation' => 'isBool',
                        'cast' => 'intval',
                        'type' => 'bool',
                        'disabled' => (Config::BANK_LV !== $selectedName && 0 !== $selectedName) ? true : false
                    ],
                    Config::BANK_EE => [
                        'title' => $this->l('Estonia banks'),
                        'validation' => 'isBool',
                        'cast' => 'intval',
                        'type' => 'bool',
                        'disabled' => (Config::BANK_EE !== $selectedName && 0 !== $selectedName) ? true : false,
                    ]
                ],
                'submit' => [
                    'title' => $this->l('Save'),
                ],
            ],
        ];
    }
}
